@@ -5,6 +5,7 @@ import (
 
 	"github.com/git-town/git-town/v12/src/cli/dialog/components"
 	"github.com/git-town/git-town/v12/src/config/configdomain"
+	"github.com/git-town/git-town/v12/src/messages"
 )
 
 const (
@@ -28,6 +29,6 @@ func GiteaToken(oldValue configdomain.GiteaToken, inputs components.TestInput) (
 		TestInput:     inputs,
 		Title:         giteaTokenTitle,
 	})
-	fmt.Printf("Gitea token: %s\n", components.FormattedSecret(token, aborted))
+	fmt.Printf(messages.GiteaToken, components.FormattedSecret(token, aborted))
 	return configdomain.GiteaToken(token), aborted, err
 }
