@@ -5,6 +5,7 @@ import (
 
 	"github.com/git-town/git-town/v12/src/cli/dialog/components"
 	"github.com/git-town/git-town/v12/src/config/configdomain"
+	"github.com/git-town/git-town/v12/src/messages"
 )
 
 const (
@@ -28,6 +29,6 @@ func GitHubToken(oldValue configdomain.GitHubToken, inputs components.TestInput)
 		TestInput:     inputs,
 		Title:         githubTokenTitle,
 	})
-	fmt.Printf("GitHub token: %s\n", components.FormattedSecret(token, aborted))
+	fmt.Printf(messages.GitHubToken, components.FormattedSecret(token, aborted))
 	return configdomain.GitHubToken(token), aborted, err
 }
