@@ -5,6 +5,7 @@ import (
 
 	"github.com/git-town/git-town/v12/src/cli/dialog/components"
 	"github.com/git-town/git-town/v12/src/config/configdomain"
+	"github.com/git-town/git-town/v12/src/messages"
 )
 
 const (
@@ -26,6 +27,6 @@ func OriginHostname(oldValue configdomain.HostingOriginHostname, inputs componen
 		TestInput:     inputs,
 		Title:         originHostnameTitle,
 	})
-	fmt.Printf("Origin hostname: %s\n", components.FormattedToken(token, aborted))
+	fmt.Printf(messages.OriginHostname, components.FormattedToken(token, aborted))
 	return configdomain.HostingOriginHostname(token), aborted, err
 }
