@@ -8,12 +8,13 @@ import (
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
 	"github.com/git-town/git-town/v12/src/gohacks/slice"
 	"github.com/git-town/git-town/v12/src/gohacks/stringers"
+	"github.com/git-town/git-town/v12/src/messages"
 )
 
 var PerennialBranchOption = gitdomain.LocalBranchName("<none> (perennial branch)") //nolint:gochecknoglobals
 
 const (
-	parentBranchTitleTemplate = `Parent Branch for %s`
+	parentBranchTitleTemplate = `Parent branch for %s`
 	parentBranchHelpTemplate  = `
 Please select the parent of branch %q or enter its number.
 Most of the time this is the main development branch (%v).
@@ -29,7 +30,7 @@ func Parent(args ParentArgs) (gitdomain.LocalBranchName, bool, error) {
 	title := fmt.Sprintf(parentBranchTitleTemplate, args.Branch)
 	help := fmt.Sprintf(parentBranchHelpTemplate, args.Branch, args.MainBranch)
 	selection, aborted, err := components.RadioList(entries, cursor, title, help, args.DialogTestInput)
-	fmt.Printf("Selected parent branch for %q: %s\n", args.Branch, components.FormattedSelection(selection.String(), aborted))
+	fmt.Printf(messages.ParentDialogSelected, args.Branch, components.FormattedSelection(selection.String(), aborted))
 	return selection, aborted, err
 }
 
