@@ -30,24 +30,24 @@ func removeConfigCommand() *cobra.Command {
 
 func executeRemoveConfig(verbose bool) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
-		Verbose:          verbose,
 		DryRun:           false,
 		OmitBranchNames:  true,
 		PrintCommands:    true,
-		ValidateIsOnline: false,
 		ValidateGitRepo:  true,
+		ValidateIsOnline: false,
+		Verbose:          verbose,
 	})
 	if err != nil {
 		return err
 	}
-	err = repo.Runner.GitConfig.RemoveLocalGitConfiguration(repo.Runner.Lineage)
+	err = repo.Runner.Config.GitConfig.RemoveLocalGitConfiguration(repo.Runner.Config.FullConfig.Lineage)
 	if err != nil {
 		return err
 	}
-	aliasNames := maps.Keys(repo.Runner.Aliases)
+	aliasNames := maps.Keys(repo.Runner.Config.FullConfig.Aliases)
 	slices.Sort(aliasNames)
 	for _, aliasName := range aliasNames {
-		if strings.HasPrefix(repo.Runner.Aliases[aliasName], "town ") {
+		if strings.HasPrefix(repo.Runner.Config.FullConfig.Aliases[aliasName], "town ") {
 			err = repo.Runner.Frontend.RemoveGitAlias(aliasName)
 			if err != nil {
 				return err
