@@ -13,12 +13,15 @@ func Execute() error {
 	rootCmd.AddCommand(completionsCmd(&rootCmd))
 	rootCmd.AddCommand(config.RootCmd())
 	rootCmd.AddCommand(continueCmd())
+	rootCmd.AddCommand(contributeCmd())
 	rootCmd.AddCommand(debug.RootCmd())
 	rootCmd.AddCommand(diffParentCommand())
 	rootCmd.AddCommand(hackCmd())
 	rootCmd.AddCommand(killCommand())
 	rootCmd.AddCommand(newPullRequestCommand())
+	rootCmd.AddCommand(observeCmd())
 	rootCmd.AddCommand(offlineCmd())
+	rootCmd.AddCommand(parkCmd())
 	rootCmd.AddCommand(proposeCommand())
 	rootCmd.AddCommand(prependCommand())
 	rootCmd.AddCommand(renameBranchCommand())
