@@ -18,7 +18,8 @@ func RootCmd() *cobra.Command {
 	debugCommand.AddCommand(enterMainBranchCmd())
 	debugCommand.AddCommand(enterParentCmd())
 	debugCommand.AddCommand(enterOriginHostname())
-	debugCommand.AddCommand(enterPerennialBranchesCmd())
+	debugCommand.AddCommand(enterPerennialBranches())
+	debugCommand.AddCommand(enterPerennialRegex())
 	debugCommand.AddCommand(enterSyncFeatureStrategy())
 	debugCommand.AddCommand(enterSyncPerennialStrategy())
 	debugCommand.AddCommand(enterSyncUpstream())
