@@ -14,8 +14,9 @@ import (
 	"github.com/git-town/git-town/v12/src/gohacks/slice"
 	"github.com/git-town/git-town/v12/src/messages"
 	"github.com/git-town/git-town/v12/src/sync"
-	"github.com/git-town/git-town/v12/src/vm/interpreter"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/undo/undoconfig"
+	fullInterpreter "github.com/git-town/git-town/v12/src/vm/interpreter/full"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/program"
 	"github.com/git-town/git-town/v12/src/vm/runstate"
 	"github.com/spf13/cobra"
@@ -45,12 +46,12 @@ func killCommand() *cobra.Command {
 
 func executeKill(args []string, dryRun, verbose bool) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
-		Verbose:          verbose,
 		DryRun:           dryRun,
 		OmitBranchNames:  false,
 		PrintCommands:    true,
-		ValidateIsOnline: false,
 		ValidateGitRepo:  true,
+		ValidateIsOnline: false,
+		Verbose:          verbose,
 	})
 	if err != nil {
 		return err
@@ -59,34 +60,42 @@ func executeKill(args []string, dryRun, verbose bool) error {
 	if err != nil || exit {
 		return err
 	}
-	steps, finalUndoProgram := killProgram(config)
+	err = validateKillConfig(config)
 	if err != nil {
 		return err
 	}
+	steps, finalUndoProgram := killProgram(config)
 	runState := runstate.RunState{
-		Command:             "kill",
-		DryRun:              dryRun,
-		RunProgram:          steps,
-		InitialActiveBranch: initialBranchesSnapshot.Active,
-		FinalUndoProgram:    finalUndoProgram,
+		BeginBranchesSnapshot: initialBranchesSnapshot,
+		BeginConfigSnapshot:   repo.ConfigSnapshot,
+		BeginStashSize:        initialStashSize,
+		Command:               "kill",
+		DryRun:                dryRun,
+		EndBranchesSnapshot:   gitdomain.EmptyBranchesSnapshot(),
+		EndConfigSnapshot:     undoconfig.EmptyConfigSnapshot(),
+		EndStashSize:          0,
+		RunProgram:            steps,
+		FinalUndoProgram:      finalUndoProgram,
 	}
-	return interpreter.Execute(interpreter.ExecuteArgs{
-		FullConfig:              config.FullConfig,
-		RunState:                &runState,
-		Run:                     repo.Runner,
+	return fullInterpreter.Execute(fullInterpreter.ExecuteArgs{
 		Connector:               nil,
 		DialogTestInputs:        &config.dialogTestInputs,
-		Verbose:                 verbose,
-		RootDir:                 repo.RootDir,
+		FullConfig:              config.FullConfig,
+		HasOpenChanges:          config.hasOpenChanges,
 		InitialBranchesSnapshot: initialBranchesSnapshot,
 		InitialConfigSnapshot:   repo.ConfigSnapshot,
 		InitialStashSize:        initialStashSize,
+		RootDir:                 repo.RootDir,
+		Run:                     repo.Runner,
+		RunState:                &runState,
+		Verbose:                 verbose,
 	})
 }
 
 type killConfig struct {
 	*configdomain.FullConfig
-	branchToKill     gitdomain.BranchInfo
+	branchNameToKill gitdomain.BranchInfo
+	branchTypeToKill configdomain.BranchType
 	branchWhenDone   gitdomain.LocalBranchName
 	dialogTestInputs components.TestInputs
 	dryRun           bool
@@ -97,15 +106,15 @@ type killConfig struct {
 
 func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, verbose bool) (*killConfig, gitdomain.BranchesSnapshot, gitdomain.StashSize, bool, error) {
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
-	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
+	branchesSnapshot, stashSize, repoStatus, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		DialogTestInputs:      dialogTestInputs,
-		FullConfig:            &repo.Runner.FullConfig,
-		Repo:                  repo,
-		Verbose:               verbose,
 		Fetch:                 true,
+		FullConfig:            &repo.Runner.Config.FullConfig,
 		HandleUnfinishedState: false,
+		Repo:                  repo,
 		ValidateIsConfigured:  true,
 		ValidateNoOpenChanges: false,
+		Verbose:               verbose,
 	})
 	if err != nil || exit {
 		return nil, branchesSnapshot, stashSize, exit, err
@@ -120,9 +129,9 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 	}
 	if branchToKill.IsLocal() {
 		err = execute.EnsureKnownBranchAncestry(branchToKill.LocalName, execute.EnsureKnownBranchAncestryArgs{
-			Config:           &repo.Runner.FullConfig,
+			Config:           &repo.Runner.Config.FullConfig,
 			AllBranches:      branchesSnapshot.Branches,
-			DefaultBranch:    repo.Runner.MainBranch,
+			DefaultBranch:    repo.Runner.Config.FullConfig.MainBranch,
 			DialogTestInputs: &dialogTestInputs,
 			Runner:           repo.Runner,
 		})
@@ -130,14 +139,8 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 			return nil, branchesSnapshot, stashSize, false, err
 		}
 	}
-	if !repo.Runner.IsFeatureBranch(branchToKill.LocalName) {
-		return nil, branchesSnapshot, stashSize, false, errors.New(messages.KillOnlyFeatureBranches)
-	}
+	branchTypeToKill := repo.Runner.Config.FullConfig.BranchType(branchNameToKill)
 	previousBranch := repo.Runner.Backend.PreviouslyCheckedOutBranch()
-	repoStatus, err := repo.Runner.Backend.RepoStatus()
-	if err != nil {
-		return nil, branchesSnapshot, stashSize, false, err
-	}
 	var branchWhenDone gitdomain.LocalBranchName
 	if branchNameToKill == branchesSnapshot.Active {
 		branchWhenDone = previousBranch
@@ -145,8 +148,9 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 		branchWhenDone = branchesSnapshot.Active
 	}
 	return &killConfig{
-		FullConfig:       &repo.Runner.FullConfig,
-		branchToKill:     *branchToKill,
+		FullConfig:       &repo.Runner.Config.FullConfig,
+		branchNameToKill: *branchToKill,
+		branchTypeToKill: branchTypeToKill,
 		branchWhenDone:   branchWhenDone,
 		dialogTestInputs: dialogTestInputs,
 		dryRun:           dryRun,
@@ -157,44 +161,68 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 }
 
 func (self killConfig) branchToKillParent() gitdomain.LocalBranchName {
-	return self.Lineage.Parent(self.branchToKill.LocalName)
+	return self.Lineage.Parent(self.branchNameToKill.LocalName)
 }
 
 func killProgram(config *killConfig) (runProgram, finalUndoProgram program.Program) {
 	prog := program.Program{}
-	killFeatureBranch(&prog, &finalUndoProgram, *config)
+	switch config.branchTypeToKill {
+	case configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeParkedBranch:
+		killFeatureBranch(&prog, &finalUndoProgram, config)
+	case configdomain.BranchTypeObservedBranch, configdomain.BranchTypeContributionBranch:
+		killLocalBranch(&prog, &finalUndoProgram, config)
+	case configdomain.BranchTypeMainBranch, configdomain.BranchTypePerennialBranch:
+		panic(fmt.Sprintf("this branch type should have been filtered in validation: %s", config.branchTypeToKill))
+	}
 	cmdhelpers.Wrap(&prog, cmdhelpers.WrapOptions{
 		DryRun:                   config.dryRun,
 		RunInGitRoot:             true,
-		StashOpenChanges:         config.initialBranch != config.branchToKill.LocalName && config.hasOpenChanges,
+		StashOpenChanges:         config.initialBranch != config.branchNameToKill.LocalName && config.hasOpenChanges,
 		PreviousBranchCandidates: gitdomain.LocalBranchNames{config.previousBranch, config.initialBranch},
 	})
 	return prog, finalUndoProgram
 }
 
 // killFeatureBranch kills the given feature branch everywhere it exists (locally and remotely).
-func killFeatureBranch(prog *program.Program, finalUndoProgram *program.Program, config killConfig) {
-	if config.branchToKill.HasTrackingBranch() && config.IsOnline() {
-		prog.Add(&opcode.DeleteTrackingBranch{Branch: config.branchToKill.RemoteName})
+func killFeatureBranch(prog *program.Program, finalUndoProgram *program.Program, config *killConfig) {
+	if config.branchNameToKill.HasTrackingBranch() && config.IsOnline() {
+		prog.Add(&opcodes.DeleteTrackingBranch{Branch: config.branchNameToKill.RemoteName})
 	}
-	if config.initialBranch == config.branchToKill.LocalName {
+	killLocalBranch(prog, finalUndoProgram, config)
+}
+
+// killFeatureBranch kills the given feature branch everywhere it exists (locally and remotely).
+func killLocalBranch(prog *program.Program, finalUndoProgram *program.Program, config *killConfig) {
+	if config.initialBranch == config.branchNameToKill.LocalName {
 		if config.hasOpenChanges {
-			prog.Add(&opcode.CommitOpenChanges{})
+			prog.Add(&opcodes.CommitOpenChanges{})
 			// update the registered initial SHA for this branch so that undo restores the just committed changes
-			prog.Add(&opcode.UpdateInitialBranchLocalSHA{Branch: config.initialBranch})
+			prog.Add(&opcodes.UpdateInitialBranchLocalSHA{Branch: config.initialBranch})
 			// when undoing, manually undo the just committed changes so that they are uncommitted again
-			finalUndoProgram.Add(&opcode.Checkout{Branch: config.branchToKill.LocalName})
-			finalUndoProgram.Add(&opcode.UndoLastCommit{})
+			finalUndoProgram.Add(&opcodes.Checkout{Branch: config.branchNameToKill.LocalName})
+			finalUndoProgram.Add(&opcodes.UndoLastCommit{})
 		}
-		prog.Add(&opcode.Checkout{Branch: config.branchWhenDone})
+		prog.Add(&opcodes.Checkout{Branch: config.branchWhenDone})
 	}
-	prog.Add(&opcode.DeleteLocalBranch{Branch: config.branchToKill.LocalName, Force: false})
+	prog.Add(&opcodes.DeleteLocalBranch{Branch: config.branchNameToKill.LocalName})
 	if !config.dryRun {
 		sync.RemoveBranchFromLineage(sync.RemoveBranchFromLineageArgs{
-			Branch:  config.branchToKill.LocalName,
+			Branch:  config.branchNameToKill.LocalName,
 			Lineage: config.Lineage,
-			Program: prog,
 			Parent:  config.branchToKillParent(),
+			Program: prog,
 		})
 	}
 }
+
+func validateKillConfig(killConfig *killConfig) error {
+	switch killConfig.branchTypeToKill {
+	case configdomain.BranchTypeContributionBranch, configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeObservedBranch, configdomain.BranchTypeParkedBranch:
+		return nil
+	case configdomain.BranchTypeMainBranch:
+		return errors.New(messages.KillCannotKillMainBranch)
+	case configdomain.BranchTypePerennialBranch:
+		return errors.New(messages.KillCannotKillPerennialBranches)
+	}
+	panic(fmt.Sprintf("unhandled branch type: %s", killConfig.branchTypeToKill))
+}
