@@ -34,6 +34,9 @@ func rootCmd() cobra.Command {
 	}, &cobra.Group{
 		ID:    "lineage",
 		Title: "Commands for stacked changes:",
+	}, &cobra.Group{
+		ID:    "types",
+		Title: "Commands to limit branch syncing:",
 	}, &cobra.Group{
 		ID:    "setup",
 		Title: "Commands to set up Git Town on your computer:",
@@ -45,7 +48,7 @@ func rootCmd() cobra.Command {
 
 func executeRoot(cmd *cobra.Command, showVersion bool) error {
 	if showVersion {
-		fmt.Println("Git Town 12.0.2")
+		fmt.Println("Git Town 12.1.0")
 		return nil
 	}
 	return cmd.Help()
