@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"errors"
 	"fmt"
 	"os"
 
@@ -18,9 +19,10 @@ import (
 	"github.com/git-town/git-town/v12/src/hosting/hostingdomain"
 	"github.com/git-town/git-town/v12/src/messages"
 	"github.com/git-town/git-town/v12/src/sync"
+	"github.com/git-town/git-town/v12/src/undo/undoconfig"
 	"github.com/git-town/git-town/v12/src/validate"
-	"github.com/git-town/git-town/v12/src/vm/interpreter"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	fullInterpreter "github.com/git-town/git-town/v12/src/vm/interpreter/full"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/program"
 	"github.com/git-town/git-town/v12/src/vm/runstate"
 	"github.com/spf13/cobra"
@@ -72,12 +74,12 @@ func shipCmd() *cobra.Command {
 
 func executeShip(args []string, message string, dryRun, verbose bool) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
-		Verbose:          verbose,
 		DryRun:           dryRun,
 		OmitBranchNames:  false,
 		PrintCommands:    true,
-		ValidateIsOnline: false,
 		ValidateGitRepo:  true,
+		ValidateIsOnline: false,
+		Verbose:          verbose,
 	})
 	if err != nil {
 		return err
@@ -97,22 +99,28 @@ func executeShip(args []string, message string, dryRun, verbose bool) error {
 		}
 	}
 	runState := runstate.RunState{
-		Command:             "ship",
-		DryRun:              dryRun,
-		InitialActiveBranch: initialBranchesSnapshot.Active,
-		RunProgram:          shipProgram(config, message),
+		BeginBranchesSnapshot: initialBranchesSnapshot,
+		BeginConfigSnapshot:   repo.ConfigSnapshot,
+		BeginStashSize:        initialStashSize,
+		Command:               "ship",
+		DryRun:                dryRun,
+		EndBranchesSnapshot:   gitdomain.EmptyBranchesSnapshot(),
+		EndConfigSnapshot:     undoconfig.EmptyConfigSnapshot(),
+		EndStashSize:          0,
+		RunProgram:            shipProgram(config, message),
 	}
-	return interpreter.Execute(interpreter.ExecuteArgs{
-		FullConfig:              config.FullConfig,
-		RunState:                &runState,
-		Run:                     repo.Runner,
+	return fullInterpreter.Execute(fullInterpreter.ExecuteArgs{
 		Connector:               config.connector,
 		DialogTestInputs:        &config.dialogTestInputs,
-		Verbose:                 verbose,
-		RootDir:                 repo.RootDir,
+		FullConfig:              config.FullConfig,
+		HasOpenChanges:          config.hasOpenChanges,
 		InitialBranchesSnapshot: initialBranchesSnapshot,
 		InitialConfigSnapshot:   repo.ConfigSnapshot,
 		InitialStashSize:        initialStashSize,
+		RootDir:                 repo.RootDir,
+		Run:                     repo.Runner,
+		RunState:                &runState,
+		Verbose:                 verbose,
 	})
 }
 
@@ -138,24 +146,20 @@ type shipConfig struct {
 
 func determineShipConfig(args []string, repo *execute.OpenRepoResult, dryRun, verbose bool) (*shipConfig, gitdomain.BranchesSnapshot, gitdomain.StashSize, bool, error) {
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
-	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
+	branchesSnapshot, stashSize, repoStatus, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		DialogTestInputs:      dialogTestInputs,
-		FullConfig:            &repo.Runner.FullConfig,
-		Repo:                  repo,
-		Verbose:               verbose,
 		Fetch:                 true,
+		FullConfig:            &repo.Runner.Config.FullConfig,
 		HandleUnfinishedState: true,
+		Repo:                  repo,
 		ValidateIsConfigured:  true,
 		ValidateNoOpenChanges: len(args) == 0,
+		Verbose:               verbose,
 	})
 	if err != nil || exit {
 		return nil, branchesSnapshot, stashSize, exit, err
 	}
 	previousBranch := repo.Runner.Backend.PreviouslyCheckedOutBranch()
-	repoStatus, err := repo.Runner.Backend.RepoStatus()
-	if err != nil {
-		return nil, branchesSnapshot, stashSize, false, err
-	}
 	remotes, err := repo.Runner.Backend.Remotes()
 	if err != nil {
 		return nil, branchesSnapshot, stashSize, false, err
@@ -171,37 +175,37 @@ func determineShipConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 			return nil, branchesSnapshot, stashSize, false, fmt.Errorf(messages.BranchDoesntExist, branchNameToShip)
 		}
 	}
-	if !repo.Runner.IsFeatureBranch(branchNameToShip) {
-		return nil, branchesSnapshot, stashSize, false, fmt.Errorf(messages.ShipNoFeatureBranch, branchNameToShip)
+	if err = validateShippableBranchType(repo.Runner.Config.FullConfig.BranchType(branchNameToShip)); err != nil {
+		return nil, branchesSnapshot, stashSize, false, err
 	}
 	err = execute.EnsureKnownBranchAncestry(branchNameToShip, execute.EnsureKnownBranchAncestryArgs{
-		Config:           &repo.Runner.FullConfig,
+		Config:           &repo.Runner.Config.FullConfig,
 		AllBranches:      branchesSnapshot.Branches,
-		DefaultBranch:    repo.Runner.MainBranch,
+		DefaultBranch:    repo.Runner.Config.FullConfig.MainBranch,
 		DialogTestInputs: &dialogTestInputs,
 		Runner:           repo.Runner,
 	})
 	if err != nil {
 		return nil, branchesSnapshot, stashSize, false, err
 	}
-	err = ensureParentBranchIsMainOrPerennialBranch(branchNameToShip, &repo.Runner.FullConfig, repo.Runner.Lineage)
+	err = ensureParentBranchIsMainOrPerennialBranch(branchNameToShip, &repo.Runner.Config.FullConfig, repo.Runner.Config.FullConfig.Lineage)
 	if err != nil {
 		return nil, branchesSnapshot, stashSize, false, err
 	}
-	targetBranchName := repo.Runner.Lineage.Parent(branchNameToShip)
+	targetBranchName := repo.Runner.Config.FullConfig.Lineage.Parent(branchNameToShip)
 	targetBranch := branchesSnapshot.Branches.FindByLocalName(targetBranchName)
 	if targetBranch == nil {
 		return nil, branchesSnapshot, stashSize, false, fmt.Errorf(messages.BranchDoesntExist, targetBranchName)
 	}
 	var proposal *hostingdomain.Proposal
-	childBranches := repo.Runner.Lineage.Children(branchNameToShip)
+	childBranches := repo.Runner.Config.FullConfig.Lineage.Children(branchNameToShip)
 	proposalsOfChildBranches := []hostingdomain.Proposal{}
 	originURL := repo.Runner.Config.OriginURL()
 	connector, err := hosting.NewConnector(hosting.NewConnectorArgs{
-		FullConfig:      &repo.Runner.FullConfig,
-		HostingPlatform: repo.Runner.HostingPlatform,
-		OriginURL:       originURL,
+		FullConfig:      &repo.Runner.Config.FullConfig,
+		HostingPlatform: repo.Runner.Config.FullConfig.HostingPlatform,
 		Log:             print.Logger{},
+		OriginURL:       originURL,
 	})
 	if err != nil {
 		return nil, branchesSnapshot, stashSize, false, err
@@ -230,7 +234,7 @@ func determineShipConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 		}
 	}
 	return &shipConfig{
-		FullConfig:               &repo.Runner.FullConfig,
+		FullConfig:               &repo.Runner.Config.FullConfig,
 		allBranches:              branchesSnapshot.Branches,
 		branchToShip:             *branchToShip,
 		canShipViaAPI:            canShipViaAPI,
@@ -252,7 +256,7 @@ func determineShipConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 
 func ensureParentBranchIsMainOrPerennialBranch(branch gitdomain.LocalBranchName, config *configdomain.FullConfig, lineage configdomain.Lineage) error {
 	parentBranch := lineage.Parent(branch)
-	if config.IsFeatureBranch(parentBranch) {
+	if !config.IsMainOrPerennialBranch(parentBranch) {
 		ancestors := lineage.Ancestors(branch)
 		ancestorsWithoutMainOrPerennial := ancestors[1:]
 		oldestAncestor := ancestorsWithoutMainOrPerennial[0]
@@ -266,44 +270,46 @@ func shipProgram(config *shipConfig, commitMessage string) program.Program {
 	if config.SyncBeforeShip {
 		// sync the parent branch
 		sync.BranchProgram(config.targetBranch, sync.BranchProgramArgs{
-			Config:      config.FullConfig,
-			BranchInfos: config.allBranches,
-			Remotes:     config.remotes,
-			Program:     &prog,
-			PushBranch:  true,
+			Config:        config.FullConfig,
+			BranchInfos:   config.allBranches,
+			InitialBranch: config.initialBranch,
+			Remotes:       config.remotes,
+			Program:       &prog,
+			PushBranch:    true,
 		})
 		// sync the branch to ship (local sync only)
 		sync.BranchProgram(config.branchToShip, sync.BranchProgramArgs{
-			Config:      config.FullConfig,
-			BranchInfos: config.allBranches,
-			Remotes:     config.remotes,
-			Program:     &prog,
-			PushBranch:  false,
+			Config:        config.FullConfig,
+			BranchInfos:   config.allBranches,
+			InitialBranch: config.initialBranch,
+			Remotes:       config.remotes,
+			Program:       &prog,
+			PushBranch:    false,
 		})
 	}
-	prog.Add(&opcode.EnsureHasShippableChanges{Branch: config.branchToShip.LocalName, Parent: config.MainBranch})
-	prog.Add(&opcode.Checkout{Branch: config.targetBranch.LocalName})
+	prog.Add(&opcodes.EnsureHasShippableChanges{Branch: config.branchToShip.LocalName, Parent: config.MainBranch})
+	prog.Add(&opcodes.Checkout{Branch: config.targetBranch.LocalName})
 	if config.canShipViaAPI {
 		// update the proposals of child branches
 		for _, childProposal := range config.proposalsOfChildBranches {
-			prog.Add(&opcode.UpdateProposalTarget{
+			prog.Add(&opcodes.UpdateProposalTarget{
 				ProposalNumber: childProposal.Number,
 				NewTarget:      config.targetBranch.LocalName,
 			})
 		}
-		prog.Add(&opcode.PushCurrentBranch{CurrentBranch: config.branchToShip.LocalName})
-		prog.Add(&opcode.ConnectorMergeProposal{
+		prog.Add(&opcodes.PushCurrentBranch{CurrentBranch: config.branchToShip.LocalName})
+		prog.Add(&opcodes.ConnectorMergeProposal{
 			Branch:          config.branchToShip.LocalName,
 			ProposalNumber:  config.proposal.Number,
 			CommitMessage:   commitMessage,
 			ProposalMessage: config.proposalMessage,
 		})
-		prog.Add(&opcode.PullCurrentBranch{})
+		prog.Add(&opcodes.PullCurrentBranch{})
 	} else {
-		prog.Add(&opcode.SquashMerge{Branch: config.branchToShip.LocalName, CommitMessage: commitMessage, Parent: config.targetBranch.LocalName})
+		prog.Add(&opcodes.SquashMerge{Branch: config.branchToShip.LocalName, CommitMessage: commitMessage, Parent: config.targetBranch.LocalName})
 	}
 	if config.remotes.HasOrigin() && config.IsOnline() {
-		prog.Add(&opcode.PushCurrentBranch{CurrentBranch: config.targetBranch.LocalName})
+		prog.Add(&opcodes.PushCurrentBranch{CurrentBranch: config.targetBranch.LocalName})
 	}
 	// NOTE: when shipping via API, we can always delete the tracking branch because:
 	// - we know we have a tracking branch (otherwise there would be no PR to ship via API)
@@ -311,18 +317,18 @@ func shipProgram(config *shipConfig, commitMessage string) program.Program {
 	// - we know we are online
 	if config.canShipViaAPI || (config.branchToShip.HasTrackingBranch() && len(config.childBranches) == 0 && config.IsOnline()) {
 		if config.ShipDeleteTrackingBranch {
-			prog.Add(&opcode.DeleteTrackingBranch{Branch: config.branchToShip.RemoteName})
+			prog.Add(&opcodes.DeleteTrackingBranch{Branch: config.branchToShip.RemoteName})
 		}
 	}
-	prog.Add(&opcode.DeleteLocalBranch{Branch: config.branchToShip.LocalName, Force: false})
+	prog.Add(&opcodes.DeleteLocalBranch{Branch: config.branchToShip.LocalName})
 	if !config.dryRun {
-		prog.Add(&opcode.DeleteParentBranch{Branch: config.branchToShip.LocalName})
+		prog.Add(&opcodes.DeleteParentBranch{Branch: config.branchToShip.LocalName})
 	}
 	for _, child := range config.childBranches {
-		prog.Add(&opcode.ChangeParent{Branch: child, Parent: config.targetBranch.LocalName})
+		prog.Add(&opcodes.ChangeParent{Branch: child, Parent: config.targetBranch.LocalName})
 	}
 	if !config.isShippingInitialBranch {
-		prog.Add(&opcode.Checkout{Branch: config.initialBranch})
+		prog.Add(&opcodes.Checkout{Branch: config.initialBranch})
 	}
 	cmdhelpers.Wrap(&prog, cmdhelpers.WrapOptions{
 		DryRun:                   config.dryRun,
@@ -332,3 +338,19 @@ func shipProgram(config *shipConfig, commitMessage string) program.Program {
 	})
 	return prog
 }
+
+func validateShippableBranchType(branchType configdomain.BranchType) error {
+	switch branchType {
+	case configdomain.BranchTypeContributionBranch:
+		return errors.New(messages.ContributionBranchCannotShip)
+	case configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeParkedBranch:
+		return nil
+	case configdomain.BranchTypeMainBranch:
+		return errors.New(messages.MainBranchCannotShip)
+	case configdomain.BranchTypeObservedBranch:
+		return errors.New(messages.ObservedBranchCannotShip)
+	case configdomain.BranchTypePerennialBranch:
+		return errors.New(messages.PerennialBranchCannotShip)
+	}
+	panic(fmt.Sprintf("unhandled branch type: %v", branchType))
+}
