@@ -6,12 +6,16 @@ import (
 	"github.com/git-town/git-town/v12/src/cli/flags"
 	"github.com/git-town/git-town/v12/src/cmd/cmdhelpers"
 	"github.com/git-town/git-town/v12/src/execute"
+	"github.com/git-town/git-town/v12/src/messages"
 	"github.com/git-town/git-town/v12/src/vm/statefile"
 	"github.com/spf13/cobra"
 )
 
 const statusResetDesc = "Resets the current suspended Git Town command"
 
+// TODO: extract this and the "status" command into a "status" subfolder,
+//
+//	similar to the "config" subfolder.
 func resetRunstateCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
@@ -29,12 +33,12 @@ func resetRunstateCommand() *cobra.Command {
 
 func executeStatusReset(verbose bool) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
-		Verbose:          verbose,
 		DryRun:           false,
 		OmitBranchNames:  false,
 		PrintCommands:    true,
-		ValidateIsOnline: false,
 		ValidateGitRepo:  true,
+		ValidateIsOnline: false,
+		Verbose:          verbose,
 	})
 	if err != nil {
 		return err
@@ -43,6 +47,6 @@ func executeStatusReset(verbose bool) error {
 	if err != nil {
 		return err
 	}
-	fmt.Println("Runstate file deleted.")
+	fmt.Println(messages.RunstateDeleted)
 	return nil
 }
