@@ -7,6 +7,7 @@ import (
 // PartialConfig contains configuration data as it is stored in the local or global Git configuration.
 type PartialConfig struct {
 	Aliases                  Aliases
+	ContributionBranches     *gitdomain.LocalBranchNames
 	GitHubToken              *GitHubToken
 	GitLabToken              *GitLabToken
 	GitUserEmail             *string
@@ -16,8 +17,11 @@ type PartialConfig struct {
 	HostingPlatform          *HostingPlatform
 	Lineage                  *Lineage
 	MainBranch               *gitdomain.LocalBranchName
+	ObservedBranches         *gitdomain.LocalBranchNames
 	Offline                  *Offline
+	ParkedBranches           *gitdomain.LocalBranchNames
 	PerennialBranches        *gitdomain.LocalBranchNames
+	PerennialRegex           *PerennialRegex
 	PushHook                 *PushHook
 	PushNewBranches          *PushNewBranches
 	ShipDeleteTrackingBranch *ShipDeleteTrackingBranch
