@@ -45,12 +45,18 @@ func AddKeyToPartialConfig(key Key, value string, config *configdomain.PartialCo
 	switch key {
 	case KeyAliasAppend:
 		config.Aliases[configdomain.AliasableCommandAppend] = value
+	case KeyAliasContribute:
+		config.Aliases[configdomain.AliasableCommandContribute] = value
 	case KeyAliasDiffParent:
 		config.Aliases[configdomain.AliasableCommandDiffParent] = value
 	case KeyAliasHack:
 		config.Aliases[configdomain.AliasableCommandHack] = value
 	case KeyAliasKill:
 		config.Aliases[configdomain.AliasableCommandKill] = value
+	case KeyAliasObserve:
+		config.Aliases[configdomain.AliasableCommandObserve] = value
+	case KeyAliasPark:
+		config.Aliases[configdomain.AliasableCommandPark] = value
 	case KeyAliasPrepend:
 		config.Aliases[configdomain.AliasableCommandPrepend] = value
 	case KeyAliasPropose:
@@ -65,6 +71,8 @@ func AddKeyToPartialConfig(key Key, value string, config *configdomain.PartialCo
 		config.Aliases[configdomain.AliasableCommandShip] = value
 	case KeyAliasSync:
 		config.Aliases[configdomain.AliasableCommandSync] = value
+	case KeyContributionBranches:
+		config.ContributionBranches = gitdomain.ParseLocalBranchNamesRef(value)
 	case KeyHostingOriginHostname:
 		config.HostingOriginHostname = configdomain.NewHostingOriginHostnameRef(value)
 	case KeyHostingPlatform:
@@ -81,10 +89,16 @@ func AddKeyToPartialConfig(key Key, value string, config *configdomain.PartialCo
 		config.GitUserName = &value
 	case KeyMainBranch:
 		config.MainBranch = gitdomain.NewLocalBranchNameRefAllowEmpty(value)
+	case KeyObservedBranches:
+		config.ObservedBranches = gitdomain.ParseLocalBranchNamesRef(value)
 	case KeyOffline:
 		config.Offline, err = configdomain.NewOfflineRef(value, KeyOffline.String())
+	case KeyParkedBranches:
+		config.ParkedBranches = gitdomain.ParseLocalBranchNamesRef(value)
 	case KeyPerennialBranches:
 		config.PerennialBranches = gitdomain.ParseLocalBranchNamesRef(value)
+	case KeyPerennialRegex:
+		config.PerennialRegex = configdomain.NewPerennialRegexRef(value)
 	case KeyPushHook:
 		config.PushHook, err = configdomain.NewPushHookRef(value, KeyPushHook.String())
 	case KeyPushNewBranches:
@@ -164,28 +178,26 @@ func (self *Access) SetLocalConfigValue(key Key, value string) error {
 }
 
 func (self *Access) UpdateDeprecatedGlobalSetting(oldKey, newKey Key, value string) {
-	fmt.Printf("I found the deprecated global setting %q.\n", oldKey)
-	fmt.Printf("I am upgrading this setting to the new format %q.\n", newKey)
+	fmt.Printf(messages.SettingDeprecatedGlobalMessage, oldKey, newKey)
 	err := self.RemoveGlobalConfigValue(oldKey)
 	if err != nil {
-		fmt.Printf("ERROR: cannot remove global Git setting %q: %v", oldKey, err)
+		fmt.Printf(messages.SettingGlobalCannotRemove, oldKey, err)
 	}
 	err = self.SetGlobalConfigValue(newKey, value)
 	if err != nil {
-		fmt.Printf("ERROR: cannot write global Git setting %q: %v", newKey, err)
+		fmt.Printf(messages.SettingGlobalCannotWrite, newKey, err)
 	}
 }
 
 func (self *Access) UpdateDeprecatedLocalSetting(oldKey, newKey Key, value string) {
-	fmt.Printf("I found the deprecated local setting %q.\n", oldKey)
-	fmt.Printf("I am upgrading this setting to the new format %q.\n", newKey)
+	fmt.Printf(messages.SettingLocalDeprecatedMessage, oldKey, newKey)
 	err := self.RemoveLocalConfigValue(oldKey)
 	if err != nil {
-		fmt.Printf("ERROR: cannot remove local Git setting %q: %v", oldKey, err)
+		fmt.Printf(messages.SettingLocalCannotRemove, oldKey, err)
 	}
 	err = self.SetLocalConfigValue(newKey, value)
 	if err != nil {
-		fmt.Printf("ERROR: cannot write local Git setting %q: %v", newKey, err)
+		fmt.Printf(messages.SettingLocalCannotWrite, newKey, err)
 	}
 }
 
@@ -230,7 +242,6 @@ func (self *Access) load(global bool) (SingleSnapshot, configdomain.PartialConfi
 		}
 		if key != KeyPerennialBranches.String() && value == "" {
 			_ = self.RemoveLocalConfigValue(*configKey)
-			fmt.Printf(messages.ConfigurationEmptyEntryDeleted, key)
 			continue
 		}
 		snapshot[*configKey] = value
