@@ -27,7 +27,7 @@ func OpenRepo(args OpenRepoArgs) (*OpenRepoResult, error) {
 		Verbose:         args.Verbose,
 	}
 	backendCommands := git.BackendCommands{
-		BackendRunner:      backendRunner,
+		Runner:             backendRunner,
 		DryRun:             args.DryRun,
 		Config:             nil, // initializing to nil here to validate the Git version before running any Git commands, setting to the correct value after that is done
 		CurrentBranchCache: &cache.LocalBranchWithPrevious{},
@@ -59,10 +59,10 @@ func OpenRepo(args OpenRepoArgs) (*OpenRepoResult, error) {
 		return nil, err
 	}
 	config, err := config.NewConfig(config.NewConfigArgs{
-		GlobalConfig: globalConfig,
-		LocalConfig:  localConfig,
 		ConfigFile:   configFile,
 		DryRun:       args.DryRun,
+		GlobalConfig: globalConfig,
+		LocalConfig:  localConfig,
 		Runner:       backendRunner,
 	})
 	if err != nil {
@@ -73,7 +73,7 @@ func OpenRepo(args OpenRepoArgs) (*OpenRepoResult, error) {
 		Config:  config,
 		Backend: backendCommands,
 		Frontend: git.FrontendCommands{
-			FrontendRunner: newFrontendRunner(newFrontendRunnerArgs{
+			Runner: newFrontendRunner(newFrontendRunnerArgs{
 				counter:          &commandsCounter,
 				dryRun:           args.DryRun,
 				getCurrentBranch: backendCommands.CurrentBranch,
