@@ -8,9 +8,9 @@ import (
 
 // ProdRunner provides Git functionality for production code.
 type ProdRunner struct {
-	*config.Config
 	Backend         BackendCommands
-	Frontend        FrontendCommands
 	CommandsCounter *gohacks.Counter
+	Config          *config.Config
 	FinalMessages   *stringslice.Collector
+	Frontend        FrontendCommands
 }
