@@ -3,16 +3,16 @@ package sync
 import (
 	"github.com/git-town/git-town/v12/src/config/configdomain"
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/program"
 )
 
 func RemoveBranchFromLineage(args RemoveBranchFromLineageArgs) {
 	childBranches := args.Lineage.Children(args.Branch)
 	for _, child := range childBranches {
-		args.Program.Add(&opcode.ChangeParent{Branch: child, Parent: args.Parent})
+		args.Program.Add(&opcodes.ChangeParent{Branch: child, Parent: args.Parent})
 	}
-	args.Program.Add(&opcode.DeleteParentBranch{Branch: args.Branch})
+	args.Program.Add(&opcodes.DeleteParentBranch{Branch: args.Branch})
 }
 
 type RemoveBranchFromLineageArgs struct {
