@@ -3,7 +3,7 @@ package sync
 import (
 	"github.com/git-town/git-town/v12/src/config/configdomain"
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/program"
 )
 
@@ -19,36 +19,55 @@ func BranchProgram(branch gitdomain.BranchInfo, args BranchProgramArgs) {
 	default:
 		ExistingBranchProgram(args.Program, branch, parentOtherWorktree, args)
 	}
-	args.Program.Add(&opcode.EndOfBranchProgram{})
+	args.Program.Add(&opcodes.EndOfBranchProgram{})
 }
 
 type BranchProgramArgs struct {
-	BranchInfos gitdomain.BranchInfos
-	Config      *configdomain.FullConfig
-	Program     *program.Program
-	PushBranch  bool
-	Remotes     gitdomain.Remotes
+	BranchInfos   gitdomain.BranchInfos
+	Config        *configdomain.FullConfig
+	InitialBranch gitdomain.LocalBranchName
+	Program       *program.Program
+	PushBranch    bool
+	Remotes       gitdomain.Remotes
 }
 
 // ExistingBranchProgram provides the opcode to sync a particular branch.
 func ExistingBranchProgram(list *program.Program, branch gitdomain.BranchInfo, parentOtherWorktree bool, args BranchProgramArgs) {
-	isFeatureBranch := args.Config.IsFeatureBranch(branch.LocalName)
-	if !isFeatureBranch && !args.Remotes.HasOrigin() {
+	isMainOrPerennialBranch := args.Config.IsMainOrPerennialBranch(branch.LocalName)
+	if isMainOrPerennialBranch && !args.Remotes.HasOrigin() {
 		// perennial branch but no remote --> this branch cannot be synced
 		return
 	}
-	list.Add(&opcode.Checkout{Branch: branch.LocalName})
-	if isFeatureBranch {
-		FeatureBranchProgram(list, branch, parentOtherWorktree, args.Config.SyncFeatureStrategy)
-	} else {
+	list.Add(&opcodes.Checkout{Branch: branch.LocalName})
+	branchType := args.Config.BranchType(branch.LocalName)
+	switch branchType {
+	case configdomain.BranchTypeFeatureBranch:
+		FeatureBranchProgram(featureBranchArgs{
+			branch:              branch,
+			parentOtherWorktree: parentOtherWorktree,
+			program:             list,
+			syncStrategy:        args.Config.SyncFeatureStrategy,
+		})
+	case configdomain.BranchTypePerennialBranch, configdomain.BranchTypeMainBranch:
 		PerennialBranchProgram(branch, args)
+	case configdomain.BranchTypeParkedBranch:
+		ParkedBranchProgram(args.InitialBranch, featureBranchArgs{
+			branch:              branch,
+			parentOtherWorktree: parentOtherWorktree,
+			program:             list,
+			syncStrategy:        args.Config.SyncFeatureStrategy,
+		})
+	case configdomain.BranchTypeContributionBranch:
+		ContributionBranchProgram(args.Program, branch)
+	case configdomain.BranchTypeObservedBranch:
+		ObservedBranchProgram(branch, args.Program)
 	}
-	if args.PushBranch && args.Remotes.HasOrigin() && args.Config.IsOnline() {
+	if args.PushBranch && args.Remotes.HasOrigin() && args.Config.IsOnline() && branchType.ShouldPush(branch.LocalName, args.InitialBranch) {
 		switch {
 		case !branch.HasTrackingBranch():
-			list.Add(&opcode.CreateTrackingBranch{Branch: branch.LocalName})
-		case !isFeatureBranch:
-			list.Add(&opcode.PushCurrentBranch{CurrentBranch: branch.LocalName})
+			list.Add(&opcodes.CreateTrackingBranch{Branch: branch.LocalName})
+		case isMainOrPerennialBranch:
+			list.Add(&opcodes.PushCurrentBranch{CurrentBranch: branch.LocalName})
 		default:
 			pushFeatureBranchProgram(list, branch.LocalName, args.Config.SyncFeatureStrategy)
 		}
@@ -56,12 +75,12 @@ func ExistingBranchProgram(list *program.Program, branch gitdomain.BranchInfo, p
 }
 
 // pullParentBranchOfCurrentFeatureBranchOpcode adds the opcode to pull updates from the parent branch of the current feature branch into the current feature branch.
-func pullParentBranchOfCurrentFeatureBranchOpcode(list *program.Program, currentBranch gitdomain.LocalBranchName, parentOtherWorktree bool, strategy configdomain.SyncFeatureStrategy) {
-	switch strategy {
+func pullParentBranchOfCurrentFeatureBranchOpcode(args featureBranchArgs) {
+	switch args.syncStrategy {
 	case configdomain.SyncFeatureStrategyMerge:
-		list.Add(&opcode.MergeParent{CurrentBranch: currentBranch, ParentActiveInOtherWorktree: parentOtherWorktree})
+		args.program.Add(&opcodes.MergeParent{CurrentBranch: args.branch.LocalName, ParentActiveInOtherWorktree: args.parentOtherWorktree})
 	case configdomain.SyncFeatureStrategyRebase:
-		list.Add(&opcode.RebaseParent{CurrentBranch: currentBranch, ParentActiveInOtherWorktree: parentOtherWorktree})
+		args.program.Add(&opcodes.RebaseParent{CurrentBranch: args.branch.LocalName, ParentActiveInOtherWorktree: args.parentOtherWorktree})
 	}
 }
 
@@ -69,18 +88,18 @@ func pullParentBranchOfCurrentFeatureBranchOpcode(list *program.Program, current
 func pullTrackingBranchOfCurrentFeatureBranchOpcode(list *program.Program, trackingBranch gitdomain.RemoteBranchName, strategy configdomain.SyncFeatureStrategy) {
 	switch strategy {
 	case configdomain.SyncFeatureStrategyMerge:
-		list.Add(&opcode.Merge{Branch: trackingBranch.BranchName()})
+		list.Add(&opcodes.Merge{Branch: trackingBranch.BranchName()})
 	case configdomain.SyncFeatureStrategyRebase:
-		list.Add(&opcode.RebaseBranch{Branch: trackingBranch.BranchName()})
+		list.Add(&opcodes.RebaseBranch{Branch: trackingBranch.BranchName()})
 	}
 }
 
 func pushFeatureBranchProgram(list *program.Program, branch gitdomain.LocalBranchName, syncFeatureStrategy configdomain.SyncFeatureStrategy) {
 	switch syncFeatureStrategy {
 	case configdomain.SyncFeatureStrategyMerge:
-		list.Add(&opcode.PushCurrentBranch{CurrentBranch: branch})
+		list.Add(&opcodes.PushCurrentBranch{CurrentBranch: branch})
 	case configdomain.SyncFeatureStrategyRebase:
-		list.Add(&opcode.ForcePushCurrentBranch{})
+		list.Add(&opcodes.ForcePushCurrentBranch{})
 	}
 }
 
@@ -88,8 +107,8 @@ func pushFeatureBranchProgram(list *program.Program, branch gitdomain.LocalBranc
 func updateCurrentPerennialBranchOpcode(list *program.Program, otherBranch gitdomain.RemoteBranchName, strategy configdomain.SyncPerennialStrategy) {
 	switch strategy {
 	case configdomain.SyncPerennialStrategyMerge:
-		list.Add(&opcode.Merge{Branch: otherBranch.BranchName()})
+		list.Add(&opcodes.Merge{Branch: otherBranch.BranchName()})
 	case configdomain.SyncPerennialStrategyRebase:
-		list.Add(&opcode.RebaseBranch{Branch: otherBranch.BranchName()})
+		list.Add(&opcodes.RebaseBranch{Branch: otherBranch.BranchName()})
 	}
 }
