@@ -3,7 +3,7 @@ package sync
 import (
 	"github.com/git-town/git-town/v12/src/cmd/cmdhelpers"
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 )
 
 // BranchesProgram syncs all given branches.
@@ -11,9 +11,9 @@ func BranchesProgram(args BranchesProgramArgs) {
 	for _, branch := range args.BranchesToSync {
 		BranchProgram(branch, args.BranchProgramArgs)
 	}
-	args.Program.Add(&opcode.CheckoutIfExists{Branch: args.InitialBranch})
+	args.Program.Add(&opcodes.CheckoutIfExists{Branch: args.InitialBranch})
 	if args.Remotes.HasOrigin() && args.ShouldPushTags && args.Config.IsOnline() {
-		args.Program.Add(&opcode.PushTags{})
+		args.Program.Add(&opcodes.PushTags{})
 	}
 	cmdhelpers.Wrap(args.Program, cmdhelpers.WrapOptions{
 		DryRun:                   args.DryRun,
