@@ -2,7 +2,7 @@ package sync
 
 import (
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 )
 
 // PerennialBranchProgram adds the opcodes to sync the perennial branch with the given name.
@@ -11,7 +11,7 @@ func PerennialBranchProgram(branch gitdomain.BranchInfo, args BranchProgramArgs)
 		updateCurrentPerennialBranchOpcode(args.Program, branch.RemoteName, args.Config.SyncPerennialStrategy)
 	}
 	if branch.LocalName == args.Config.MainBranch && args.Remotes.HasUpstream() && args.Config.SyncUpstream.Bool() {
-		args.Program.Add(&opcode.FetchUpstream{Branch: args.Config.MainBranch})
-		args.Program.Add(&opcode.RebaseBranch{Branch: gitdomain.NewBranchName("upstream/" + args.Config.MainBranch.String())})
+		args.Program.Add(&opcodes.FetchUpstream{Branch: args.Config.MainBranch})
+		args.Program.Add(&opcodes.RebaseBranch{Branch: gitdomain.NewBranchName("upstream/" + args.Config.MainBranch.String())})
 	}
 }
