@@ -7,7 +7,7 @@ import (
 	"github.com/git-town/git-town/v12/src/git/gitdomain"
 	"github.com/git-town/git-town/v12/src/undo/undobranches"
 	"github.com/git-town/git-town/v12/src/undo/undodomain"
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/program"
 	"github.com/shoenig/test/must"
 )
@@ -76,18 +76,15 @@ func TestChanges(t *testing.T) {
 			PerennialBranches: gitdomain.NewLocalBranchNames(),
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcode.DeleteLocalBranch{
-				Branch: gitdomain.NewLocalBranchName("branch-1"),
-				Force:  true,
-			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("branch-1")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -133,17 +130,17 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.CreateBranch{
+			&opcodes.CreateBranch{
 				Branch:        gitdomain.NewLocalBranchName("branch-1"),
 				StartingPoint: gitdomain.NewSHA("111111").Location(),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("branch-1")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("branch-1")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -222,25 +219,25 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 				Hard:        true,
 			},
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("333333"),
 				SetToSHA:    gitdomain.NewSHA("111111"),
 				Hard:        true,
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -312,19 +309,19 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.DeleteTrackingBranch{
+			&opcodes.DeleteTrackingBranch{
 				Branch: gitdomain.NewRemoteBranchName("origin/perennial-branch"),
 			},
-			&opcode.DeleteTrackingBranch{
+			&opcodes.DeleteTrackingBranch{
 				Branch: gitdomain.NewRemoteBranchName("origin/feature-branch"),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -396,21 +393,15 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.DeleteLocalBranch{
-				Branch: gitdomain.NewLocalBranchName("perennial-branch"),
-				Force:  true,
-			},
-			&opcode.DeleteLocalBranch{
-				Branch: gitdomain.NewLocalBranchName("feature-branch"),
-				Force:  true,
-			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -470,28 +461,22 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.DeleteTrackingBranch{
+			&opcodes.DeleteTrackingBranch{
 				Branch: gitdomain.NewRemoteBranchName("origin/perennial-branch"),
 			},
-			&opcode.DeleteTrackingBranch{
+			&opcodes.DeleteTrackingBranch{
 				Branch: gitdomain.NewRemoteBranchName("origin/feature-branch"),
 			},
-			&opcode.DeleteLocalBranch{
-				Branch: gitdomain.NewLocalBranchName("perennial-branch"),
-				Force:  true,
-			},
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcode.DeleteLocalBranch{
-				Branch: gitdomain.NewLocalBranchName("feature-branch"),
-				Force:  true,
-			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -569,25 +554,25 @@ func TestChanges(t *testing.T) {
 			PushHook:          true,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 				Hard:        true,
 			},
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("333333"),
 				SetToSHA:    gitdomain.NewSHA("111111"),
 				Hard:        true,
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -665,20 +650,20 @@ func TestChanges(t *testing.T) {
 			PushHook:          true,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// It doesn't reset the remote perennial branch since those are assumed to be protected against force-pushes
 			// and we can't revert the commit on it since we cannot change the local perennial branch here.
-			&opcode.ResetRemoteBranchToSHA{
+			&opcodes.ResetRemoteBranchToSHA{
 				Branch:      gitdomain.NewRemoteBranchName("origin/feature-branch"),
 				SetToSHA:    gitdomain.NewSHA("333333"),
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -774,24 +759,24 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
-			Config:        &config,
-			InitialBranch: before.Active,
-			FinalBranch:   after.Active,
+			BeginBranch: before.Active,
+			Config:      &config,
+			EndBranch:   after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{
 				gitdomain.NewSHA("444444"),
 			},
 		})
 		wantProgram := program.Program{
 			// revert the commit on the perennial branch
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcode.RevertCommit{SHA: gitdomain.NewSHA("444444")},
-			&opcode.PushCurrentBranch{CurrentBranch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.RevertCommit{SHA: gitdomain.NewSHA("444444")},
+			&opcodes.PushCurrentBranch{CurrentBranch: gitdomain.NewLocalBranchName("main")},
 			// reset the feature branch to the previous SHA
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcode.ResetCurrentBranchToSHA{MustHaveSHA: gitdomain.NewSHA("666666"), SetToSHA: gitdomain.NewSHA("333333"), Hard: true},
-			&opcode.ForcePushCurrentBranch{},
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.ResetCurrentBranchToSHA{MustHaveSHA: gitdomain.NewSHA("666666"), SetToSHA: gitdomain.NewSHA("333333"), Hard: true},
+			&opcodes.ForcePushCurrentBranch{},
 			// check out the initial branch
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -874,23 +859,23 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
-			Config:        &config,
-			InitialBranch: before.Active,
-			FinalBranch:   after.Active,
+			BeginBranch: before.Active,
+			Config:      &config,
+			EndBranch:   after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{
 				gitdomain.NewSHA("444444"),
 			},
 		})
 		wantProgram := program.Program{
 			// revert the undoable commit on the main branch
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcode.RevertCommit{SHA: gitdomain.NewSHA("444444")},
-			&opcode.PushCurrentBranch{CurrentBranch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.RevertCommit{SHA: gitdomain.NewSHA("444444")},
+			&opcodes.PushCurrentBranch{CurrentBranch: gitdomain.NewLocalBranchName("main")},
 			// re-create the feature branch
-			&opcode.CreateBranch{Branch: gitdomain.NewLocalBranchName("feature-branch"), StartingPoint: gitdomain.NewSHA("222222").Location()},
-			&opcode.CreateTrackingBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CreateBranch{Branch: gitdomain.NewLocalBranchName("feature-branch"), StartingPoint: gitdomain.NewSHA("222222").Location()},
+			&opcodes.CreateTrackingBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 			// check out the initial branch
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -992,25 +977,25 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// It doesn't revert the perennial branch because it cannot force-push the changes to the remote branch.
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("555555"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 				Hard:        true,
 			},
-			&opcode.ResetRemoteBranchToSHA{
+			&opcodes.ResetRemoteBranchToSHA{
 				Branch:      gitdomain.NewRemoteBranchName("origin/feature-branch"),
 				MustHaveSHA: gitdomain.NewSHA("666666"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -1088,25 +1073,25 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("333333"),
 				Hard:        true,
 			},
-			&opcode.Checkout{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcode.ResetCurrentBranchToSHA{
+			&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.ResetCurrentBranchToSHA{
 				MustHaveSHA: gitdomain.NewSHA("222222"),
 				SetToSHA:    gitdomain.NewSHA("111111"),
 				Hard:        true,
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -1184,19 +1169,19 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// It doesn't revert the remote perennial branch because it cannot force-push the changes to it.
-			&opcode.ResetRemoteBranchToSHA{
+			&opcodes.ResetRemoteBranchToSHA{
 				Branch:      gitdomain.NewRemoteBranchName("origin/feature-branch"),
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("333333"),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -1268,21 +1253,21 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcode.CreateBranch{
+			&opcodes.CreateBranch{
 				Branch:        gitdomain.NewLocalBranchName("feature-branch"),
 				StartingPoint: gitdomain.NewSHA("222222").Location(),
 			},
-			&opcode.CreateBranch{
+			&opcodes.CreateBranch{
 				Branch:        gitdomain.NewLocalBranchName("perennial-branch"),
 				StartingPoint: gitdomain.NewSHA("111111").Location(),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -1354,19 +1339,19 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// don't re-create the tracking branch for the perennial branch
 			// because those are protected
-			&opcode.CreateRemoteBranch{
+			&opcodes.CreateRemoteBranch{
 				Branch: gitdomain.NewLocalBranchName("feature-branch"),
 				SHA:    gitdomain.NewSHA("222222"),
 			},
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
@@ -1435,16 +1420,16 @@ func TestChanges(t *testing.T) {
 			PushHook:          false,
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
+			BeginBranch:              before.Active,
 			Config:                   &config,
-			InitialBranch:            before.Active,
-			FinalBranch:              after.Active,
+			EndBranch:                after.Active,
 			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// No changes should happen here since all changes were syncs on perennial branches.
 			// We don't want to undo these commits because that would undo commits
 			// already committed to perennial branches by others for everybody on the team.
-			&opcode.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
+			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
 	})
