@@ -1,7 +1,7 @@
 package undoconfig
 
 import (
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/program"
 )
 
@@ -21,31 +21,31 @@ func NewConfigDiffs(before, after ConfigSnapshot) ConfigDiffs {
 func (self ConfigDiffs) UndoProgram() program.Program {
 	result := program.Program{}
 	for _, key := range self.Global.Added {
-		result.Add(&opcode.RemoveGlobalConfig{Key: key})
+		result.Add(&opcodes.RemoveGlobalConfig{Key: key})
 	}
 	for key, value := range self.Global.Removed {
-		result.Add(&opcode.SetGlobalConfig{
+		result.Add(&opcodes.SetGlobalConfig{
 			Key:   key,
 			Value: value,
 		})
 	}
 	for key, change := range self.Global.Changed {
-		result.Add(&opcode.SetGlobalConfig{
+		result.Add(&opcodes.SetGlobalConfig{
 			Key:   key,
 			Value: change.Before,
 		})
 	}
 	for _, key := range self.Local.Added {
-		result.Add(&opcode.RemoveLocalConfig{Key: key})
+		result.Add(&opcodes.RemoveLocalConfig{Key: key})
 	}
 	for key, value := range self.Local.Removed {
-		result.Add(&opcode.SetLocalConfig{
+		result.Add(&opcodes.SetLocalConfig{
 			Key:   key,
 			Value: value,
 		})
 	}
 	for key, change := range self.Local.Changed {
-		result.Add(&opcode.SetLocalConfig{
+		result.Add(&opcodes.SetLocalConfig{
 			Key:   key,
 			Value: change.Before,
 		})
