@@ -3,7 +3,7 @@ package shared_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v12/src/vm/opcode"
+	"github.com/git-town/git-town/v12/src/vm/opcodes"
 	"github.com/git-town/git-town/v12/src/vm/shared"
 	"github.com/shoenig/test/must"
 )
@@ -11,8 +11,8 @@ import (
 func TestIsEndOfBranchProgramOpcode(t *testing.T) {
 	t.Parallel()
 	tests := map[shared.Opcode]bool{
-		&opcode.EndOfBranchProgram{}: true,
-		&opcode.AbortMerge{}:         false,
+		&opcodes.EndOfBranchProgram{}: true,
+		&opcodes.AbortMerge{}:         false,
 	}
 	for give, want := range tests {
 		have := shared.IsEndOfBranchProgramOpcode(give)
