@@ -132,6 +132,15 @@ func (self *TestCommands) CreateCommit(commit git.Commit) {
 	self.MustRun("git", commands...)
 }
 
+// CreateObservedBranches creates perennial branches with the given names in this repository.
+func (self *TestCommands) CreateContributionBranches(names ...gitdomain.LocalBranchName) {
+	main := gitdomain.NewLocalBranchName("main")
+	for _, name := range names {
+		self.CreateBranch(name, main)
+	}
+	asserts.NoError(self.Config.AddToContributionBranches(names...))
+}
+
 // CreateFeatureBranch creates a feature branch with the given name in this repository.
 func (self *TestCommands) CreateFeatureBranch(name gitdomain.LocalBranchName) {
 	err := self.RunMany([][]string{
@@ -152,6 +161,23 @@ func (self *TestCommands) CreateFile(name, content string) {
 	asserts.NoError(os.WriteFile(filePath, []byte(content), 0o700))
 }
 
+// CreateObservedBranches creates perennial branches with the given names in this repository.
+func (self *TestCommands) CreateObservedBranches(names ...gitdomain.LocalBranchName) {
+	main := gitdomain.NewLocalBranchName("main")
+	for _, name := range names {
+		self.CreateBranch(name, main)
+	}
+	asserts.NoError(self.Config.AddToObservedBranches(names...))
+}
+
+// CreateParkedBranches creates perennial branches with the given names in this repository.
+func (self *TestCommands) CreateParkedBranches(names ...gitdomain.LocalBranchName) {
+	for _, name := range names {
+		self.CreateFeatureBranch(name)
+	}
+	asserts.NoError(self.Config.AddToParkedBranches(names...))
+}
+
 // CreatePerennialBranches creates perennial branches with the given names in this repository.
 func (self *TestCommands) CreatePerennialBranches(names ...gitdomain.LocalBranchName) {
 	main := gitdomain.NewLocalBranchName("main")
@@ -255,9 +281,9 @@ func (self *TestCommands) GlobalGitConfig(name gitconfig.Key) *string {
 }
 
 // HasBranchesOutOfSync indicates whether one or more local branches are out of sync with their tracking branch.
-func (self *TestCommands) HasBranchesOutOfSync() bool {
+func (self *TestCommands) HasBranchesOutOfSync() (bool, string) {
 	output := self.MustQuery("git", "for-each-ref", "--format=%(refname:short) %(upstream:track)", "refs/heads")
-	return strings.Contains(output, "[")
+	return strings.Contains(output, "["), output
 }
 
 // HasFile indicates whether this repository contains a file with the given name and content.
@@ -278,7 +304,7 @@ func (self *TestCommands) HasFile(name, content string) string {
 func (self *TestCommands) LineageTable() datatable.DataTable {
 	result := datatable.DataTable{}
 	self.Config.Reload()
-	lineage := self.Config.Lineage
+	lineage := self.Config.FullConfig.Lineage
 	result.AddRow("BRANCH", "PARENT")
 	for _, branchName := range lineage.BranchNames() {
 		result.AddRow(branchName.String(), lineage[branchName].String())
@@ -348,7 +374,7 @@ func (self *TestCommands) RemoveMainBranchConfiguration() {
 
 // RemovePerennialBranchConfiguration removes the configuration entry for the perennial branches.
 func (self *TestCommands) RemovePerennialBranchConfiguration() error {
-	return self.GitConfig.RemoveLocalConfigValue(gitconfig.KeyPerennialBranches)
+	return self.Config.GitConfig.RemoveLocalConfigValue(gitconfig.KeyPerennialBranches)
 }
 
 // RemoveRemote deletes the Git remote with the given name.
@@ -441,7 +467,7 @@ func (self *TestCommands) VerifyNoGitTownConfiguration() error {
 		return fmt.Errorf("unexpected Git Town configuration:\n%s", output)
 	}
 	self.Config.Reload()
-	for aliasName, aliasValue := range self.Config.Aliases {
+	for aliasName, aliasValue := range self.Config.FullConfig.Aliases {
 		if strings.HasPrefix(aliasValue, "town ") {
 			return fmt.Errorf("unexpected Git Town alias %q with value %q", aliasName, aliasValue)
 		}
