@@ -37,14 +37,14 @@ func TestTestCommands(t *testing.T) {
 		runtime := testruntime.Create(t)
 		runtime.CreateCommit(git.Commit{
 			Branch:      gitdomain.NewLocalBranchName("initial"),
-			FileName:    "file1",
 			FileContent: "hello",
+			FileName:    "file1",
 			Message:     "first commit",
 		})
 		runtime.CreateCommit(git.Commit{
 			Branch:      gitdomain.NewLocalBranchName("initial"),
-			FileName:    "file2",
 			FileContent: "hello again",
+			FileName:    "file2",
 			Message:     "second commit",
 		})
 		commits := runtime.Commits([]string{"FILE NAME", "FILE CONTENT"}, gitdomain.NewLocalBranchName("initial"))
@@ -106,7 +106,7 @@ func TestTestCommands(t *testing.T) {
 		runtime := testruntime.CreateGitTown(t)
 		runtime.CreateFeatureBranch(gitdomain.NewLocalBranchName("f1"))
 		runtime.CreateChildFeatureBranch(gitdomain.NewLocalBranchName("f1a"), gitdomain.NewLocalBranchName("f1"))
-		output, err := runtime.BackendRunner.QueryTrim("git-town", "config")
+		output, err := runtime.Runner.QueryTrim("git-town", "config")
 		must.NoError(t, err)
 		output = stripansi.Strip(output)
 		if !strings.Contains(output, "Branch Lineage:\n  main\n    f1\n      f1a") {
@@ -120,8 +120,8 @@ func TestTestCommands(t *testing.T) {
 			runtime := testruntime.Create(t)
 			runtime.CreateCommit(git.Commit{
 				Branch:      gitdomain.NewLocalBranchName("initial"),
-				FileName:    "hello.txt",
 				FileContent: "hello world",
+				FileName:    "hello.txt",
 				Message:     "test commit",
 			})
 			commits := runtime.Commits([]string{"FILE NAME", "FILE CONTENT"}, gitdomain.NewLocalBranchName("initial"))
@@ -136,11 +136,11 @@ func TestTestCommands(t *testing.T) {
 			t.Parallel()
 			runtime := testruntime.Create(t)
 			runtime.CreateCommit(git.Commit{
-				Branch:      gitdomain.NewLocalBranchName("initial"),
-				FileName:    "hello.txt",
-				FileContent: "hello world",
-				Message:     "test commit",
 				Author:      "developer <developer@example.com>",
+				Branch:      gitdomain.NewLocalBranchName("initial"),
+				FileContent: "hello world",
+				FileName:    "hello.txt",
+				Message:     "test commit",
 			})
 			commits := runtime.Commits([]string{"FILE NAME", "FILE CONTENT"}, gitdomain.NewLocalBranchName("initial"))
 			must.Len(t, 1, commits)
@@ -157,8 +157,8 @@ func TestTestCommands(t *testing.T) {
 		runtime := testruntime.CreateGitTown(t)
 		runtime.CreateFeatureBranch(gitdomain.NewLocalBranchName("f1"))
 		runtime.Config.Reload()
-		must.True(t, runtime.Config.IsFeatureBranch(gitdomain.NewLocalBranchName("f1")))
-		lineageHave := runtime.Config.Lineage
+		must.False(t, runtime.Config.FullConfig.IsMainOrPerennialBranch(gitdomain.NewLocalBranchName("f1")))
+		lineageHave := runtime.Config.FullConfig.Lineage
 		lineageWant := configdomain.Lineage{}
 		lineageWant[gitdomain.NewLocalBranchName("f1")] = gitdomain.NewLocalBranchName("main")
 		must.Eq(t, lineageWant, lineageHave)
@@ -192,9 +192,9 @@ func TestTestCommands(t *testing.T) {
 		must.NoError(t, err)
 		want := gitdomain.NewLocalBranchNames("main", "initial", "p1", "p2")
 		must.Eq(t, want, branches)
-		runtime.Reload()
-		must.True(t, runtime.IsPerennialBranch(gitdomain.NewLocalBranchName("p1")))
-		must.True(t, runtime.IsPerennialBranch(gitdomain.NewLocalBranchName("p2")))
+		runtime.Config.Reload()
+		must.True(t, runtime.Config.FullConfig.IsPerennialBranch(gitdomain.NewLocalBranchName("p1")))
+		must.True(t, runtime.Config.FullConfig.IsPerennialBranch(gitdomain.NewLocalBranchName("p2")))
 	})
 
 	t.Run("Fetch", func(t *testing.T) {
@@ -210,8 +210,8 @@ func TestTestCommands(t *testing.T) {
 		runtime := testruntime.Create(t)
 		runtime.CreateCommit(git.Commit{
 			Branch:      gitdomain.NewLocalBranchName("initial"),
-			FileName:    "hello.txt",
 			FileContent: "hello world",
+			FileName:    "hello.txt",
 			Message:     "commit",
 		})
 		commits := runtime.CommitsInBranch(gitdomain.NewLocalBranchName("initial"), []string{})
@@ -244,7 +244,7 @@ func TestTestCommands(t *testing.T) {
 			runner.StageFiles("file1")
 			runner.CommitStagedChanges("stuff")
 			runner.PushBranchToRemote(gitdomain.NewLocalBranchName("branch1"), gitdomain.OriginRemote)
-			have := runner.HasBranchesOutOfSync()
+			have, _ := runner.HasBranchesOutOfSync()
 			must.False(t, have)
 		})
 
@@ -256,7 +256,7 @@ func TestTestCommands(t *testing.T) {
 			env.DevRepo.CreateFile("file1", "content")
 			env.DevRepo.StageFiles("file1")
 			env.DevRepo.CommitStagedChanges("stuff")
-			have := env.DevRepo.HasBranchesOutOfSync()
+			have, _ := env.DevRepo.HasBranchesOutOfSync()
 			must.True(t, have)
 		})
 
@@ -271,7 +271,7 @@ func TestTestCommands(t *testing.T) {
 			env.OriginRepo.CommitStagedChanges("stuff")
 			env.OriginRepo.CheckoutBranch(gitdomain.NewLocalBranchName("initial"))
 			env.DevRepo.Fetch()
-			have := env.DevRepo.HasBranchesOutOfSync()
+			have, _ := env.DevRepo.HasBranchesOutOfSync()
 			must.True(t, have)
 		})
 	})
@@ -381,7 +381,12 @@ func TestTestCommands(t *testing.T) {
 	t.Run("SHAForCommit", func(t *testing.T) {
 		t.Parallel()
 		repo := testruntime.Create(t)
-		repo.CreateCommit(git.Commit{Branch: gitdomain.NewLocalBranchName("initial"), FileName: "foo", FileContent: "bar", Message: "commit"})
+		repo.CreateCommit(git.Commit{
+			Branch:      gitdomain.NewLocalBranchName("initial"),
+			FileContent: "bar",
+			FileName:    "foo",
+			Message:     "commit",
+		})
 		sha := repo.SHAForCommit("commit")
 		must.EqOp(t, 7, len(sha))
 	})
