@@ -105,6 +105,15 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^a known remote feature branch "([^"]*)"$`, func(branchText string) error {
+		branch := gitdomain.NewLocalBranchName(branchText)
+		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+		// we are creating a remote branch in the remote repo --> it is a local branch there
+		state.fixture.OriginRepo.CreateBranch(branch, gitdomain.NewLocalBranchName("main"))
+		state.fixture.DevRepo.TestCommands.Fetch()
+		return nil
+	})
+
 	suite.Step(`^a merge is now in progress$`, func() error {
 		if !state.fixture.DevRepo.HasMergeInProgress() {
 			return errors.New("expected merge in progress")
@@ -126,6 +135,16 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^a parked branch "([^"]+)"$`, func(branchText string) error {
+		branch := gitdomain.NewLocalBranchName(branchText)
+		state.fixture.DevRepo.CreateParkedBranches(branch)
+		state.initialLocalBranches = append(state.initialLocalBranches, branch)
+		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+		state.initialLineage.AddRow(branchText, "main")
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+		return nil
+	})
+
 	suite.Step(`^a perennial branch "([^"]+)"$`, func(branchText string) error {
 		branch := gitdomain.NewLocalBranchName(branchText)
 		state.fixture.DevRepo.CreatePerennialBranches(branch)
@@ -158,8 +177,9 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^all branches are now synchronized$`, func() error {
-		if state.fixture.DevRepo.HasBranchesOutOfSync() {
-			return errors.New("expected no branches out of sync")
+		branchesOutOfSync, output := state.fixture.DevRepo.HasBranchesOutOfSync()
+		if branchesOutOfSync {
+			return errors.New("unexpected out of sync:\n" + output)
 		}
 		return nil
 	})
@@ -200,9 +220,82 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^branch "([^"]+)" is (?:now|still) a contribution branch`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		if !state.fixture.DevRepo.Config.FullConfig.IsContributionBranch(branch) {
+			return fmt.Errorf(
+				"branch %q isn't contribution as expected.\nContribution branches: %s",
+				branch,
+				strings.Join(state.fixture.DevRepo.Config.FullConfig.ContributionBranches.Strings(), ", "),
+			)
+		}
+		return nil
+	})
+
+	suite.Step(`^branch "([^"]+)" is (?:now|still) a feature branch`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		if state.fixture.DevRepo.Config.FullConfig.BranchType(branch) != configdomain.BranchTypeFeatureBranch {
+			return fmt.Errorf("branch %q isn't a feature branch as expected", branch)
+		}
+		return nil
+	})
+
+	suite.Step(`^branch "([^"]+)" is (?:now|still) observed`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		if !state.fixture.DevRepo.Config.FullConfig.IsObservedBranch(branch) {
+			return fmt.Errorf(
+				"branch %q isn't observed as expected.\nObserved branches: %s",
+				branch,
+				strings.Join(state.fixture.DevRepo.Config.FullConfig.ObservedBranches.Strings(), ", "),
+			)
+		}
+		return nil
+	})
+
+	suite.Step(`^branch "([^"]+)" is now parked`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		if !state.fixture.DevRepo.Config.FullConfig.IsParkedBranch(branch) {
+			return fmt.Errorf(
+				"branch %q isn't parked as expected.\nParked branches: %s",
+				branch,
+				strings.Join(state.fixture.DevRepo.Config.FullConfig.ParkedBranches.Strings(), ", "),
+			)
+		}
+		return nil
+	})
+
+	suite.Step(`^branch "([^"]+)" is (?:now|still) perennial`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		if !state.fixture.DevRepo.Config.FullConfig.IsPerennialBranch(branch) {
+			return fmt.Errorf(
+				"branch %q isn't perennial as expected.\nPerennial branches: %s",
+				branch,
+				strings.Join(state.fixture.DevRepo.Config.FullConfig.PerennialBranches.Strings(), ", "),
+			)
+		}
+		return nil
+	})
+
+	suite.Step(`^branch "([^"]+)" is now a feature branch`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		if state.fixture.DevRepo.Config.FullConfig.IsParkedBranch(branch) {
+			return fmt.Errorf("branch %q is parked", branch)
+		}
+		if state.fixture.DevRepo.Config.FullConfig.IsObservedBranch(branch) {
+			return fmt.Errorf("branch %q is observed", branch)
+		}
+		if state.fixture.DevRepo.Config.FullConfig.IsContributionBranch(branch) {
+			return fmt.Errorf("branch %q is contribution", branch)
+		}
+		if state.fixture.DevRepo.Config.FullConfig.IsPerennialBranch(branch) {
+			return fmt.Errorf("branch %q is perennial", branch)
+		}
+		return nil
+	})
+
 	suite.Step(`^display "([^"]+)"$`, func(command string) error {
 		parts := strings.Split(command, " ")
-		output, err := state.fixture.DevRepo.BackendRunner.Query(parts[0], parts[1:]...)
+		output, err := state.fixture.DevRepo.Runner.Query(parts[0], parts[1:]...)
 		fmt.Println("XXXXXXXXXXXXXXXXX " + strings.ToUpper(command) + " START XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX")
 		fmt.Println(output)
 		fmt.Println("XXXXXXXXXXXXXXXXX " + strings.ToUpper(command) + " END XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX")
@@ -217,7 +310,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
-	suite.Step(`^file "([^"]*)" still has content "([^"]*)"$`, func(file, expectedContent string) error {
+	suite.Step(`^file "([^"]*)" (?:now|still) has content "([^"]*)"$`, func(file, expectedContent string) error {
 		actualContent := state.fixture.DevRepo.FileContent(file)
 		if expectedContent != actualContent {
 			return fmt.Errorf("file content does not match\n\nEXPECTED: %q\n\nACTUAL:\n\n%q\n----------------------------", expectedContent, actualContent)
@@ -270,13 +363,13 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return state.fixture.DevRepo.SetGitAlias(*aliasableCommand, value)
 	})
 
-	suite.Step(`^global Git setting "alias\.(.*?)" now doesn't exist$`, func(name string) error {
+	suite.Step(`^global Git setting "alias\.(.*?)" (?:now|still) doesn't exist$`, func(name string) error {
 		key := gitconfig.ParseKey("alias." + name)
 		if key == nil {
 			return errors.New("key not found")
 		}
 		aliasableCommand := gitconfig.AliasableCommandForKey(*key)
-		command, has := state.fixture.DevRepo.Config.Aliases[*aliasableCommand]
+		command, has := state.fixture.DevRepo.Config.FullConfig.Aliases[*aliasableCommand]
 		if !has {
 			return nil
 		}
@@ -307,7 +400,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return state.fixture.DevRepo.Config.GitConfig.SetGlobalConfigValue(*configKey, value)
 	})
 
-	suite.Step(`^global Git Town setting "([^"]*)" now doesn't exist$`, func(name string) error {
+	suite.Step(`^global Git Town setting "([^"]*)" (?:now|still) doesn't exist$`, func(name string) error {
 		configKey := gitconfig.ParseKey("git-town." + name)
 		newValue := state.fixture.DevRepo.TestCommands.GlobalGitConfig(*configKey)
 		if newValue != nil {
@@ -438,10 +531,9 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 
 	suite.Step(`^I add commit "([^"]*)" to the "([^"]*)" branch`, func(message, branch string) error {
 		state.fixture.DevRepo.CreateCommit(git.Commit{
-			Branch:      gitdomain.NewLocalBranchName(branch),
-			FileName:    "new_file",
-			FileContent: "new content",
-			Message:     message,
+			Branch:   gitdomain.NewLocalBranchName(branch),
+			FileName: "new_file",
+			Message:  message,
 		})
 		return nil
 	})
@@ -596,7 +688,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 			return fmt.Errorf("text not found:\n%s\n\nactual text:\n%s", expected.Content, state.runOutput)
 		}
 		if state.runExitCode == 0 {
-			return fmt.Errorf("expected exit code %d", state.runExitCode)
+			return fmt.Errorf("unexpected exit code %d", state.runExitCode)
 		}
 		return nil
 	})
@@ -767,6 +859,15 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return fmt.Errorf(`expected local setting "main-branch" to be %v, but was %v`, want, have)
 	})
 
+	suite.Step(`^local Git Town setting "perennial-regex" is now "([^"]*)"$`, func(wantStr string) error {
+		have := state.fixture.DevRepo.Config.LocalGitConfig.PerennialRegex
+		want := configdomain.PerennialRegex(wantStr)
+		if *have != want {
+			return fmt.Errorf(`expected local setting "perennial-regex" to be %q, but was %q`, want, have)
+		}
+		return nil
+	})
+
 	suite.Step(`^local Git Town setting "push-hook" is (:?now|still) not set$`, func() error {
 		have := state.fixture.DevRepo.Config.LocalGitConfig.PushHook
 		if have == nil {
@@ -927,8 +1028,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^no lineage exists now$`, func() error {
-		if state.fixture.DevRepo.Config.ContainsLineage() {
-			lineage := state.fixture.DevRepo.Config.Lineage
+		if state.fixture.DevRepo.Config.FullConfig.ContainsLineage() {
+			lineage := state.fixture.DevRepo.Config.FullConfig.Lineage
 			return fmt.Errorf("unexpected Git Town lineage information: %+v", lineage)
 		}
 		return nil
@@ -966,7 +1067,7 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 	})
 
 	suite.Step(`^offline mode is disabled$`, func() error {
-		isOffline := state.fixture.DevRepo.Config.Offline
+		isOffline := state.fixture.DevRepo.Config.FullConfig.Offline
 		if isOffline {
 			return errors.New("expected to not be offline but am")
 		}
@@ -1051,6 +1152,17 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^a contribution branch "([^"]+)"$`, func(branch string) error {
+		state.fixture.DevRepo.CreateBranch(gitdomain.NewLocalBranchName(branch), "main")
+		return state.fixture.DevRepo.Config.SetContributionBranches(gitdomain.NewLocalBranchNames(branch))
+	})
+
+	suite.Step(`^the contribution branches "([^"]+)" and "([^"]+)"$`, func(branch1, branch2 string) error {
+		state.fixture.DevRepo.CreateBranch(gitdomain.NewLocalBranchName(branch1), "main")
+		state.fixture.DevRepo.CreateBranch(gitdomain.NewLocalBranchName(branch2), "main")
+		return state.fixture.DevRepo.Config.SetContributionBranches(gitdomain.NewLocalBranchNames(branch1, branch2))
+	})
+
 	suite.Step(`^the coworker fetches updates$`, func() error {
 		state.fixture.CoworkerRepo.Fetch()
 		return nil
@@ -1091,21 +1203,26 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
-	suite.Step(`^the current branch is a (local )?(feature|perennial) branch "([^"]*)"$`, func(localStr, branchType, branchName string) error {
+	suite.Step(`^the current branch is an? (local )?(feature|perennial|parked|contribution|observed) branch "([^"]*)"$`, func(localStr, branchType, branchName string) error {
 		branch := gitdomain.NewLocalBranchName(branchName)
 		isLocal := localStr != ""
 		switch branchType {
 		case "feature":
 			state.fixture.DevRepo.CreateFeatureBranch(branch)
+			state.initialLineage.AddRow(branchName, "main")
 		case "perennial":
 			state.fixture.DevRepo.CreatePerennialBranches(branch)
+		case "parked":
+			state.fixture.DevRepo.CreateParkedBranches(branch)
+			state.initialLineage.AddRow(branchName, "main")
+		case "contribution":
+			state.fixture.DevRepo.CreateContributionBranches(branch)
+		case "observed":
+			state.fixture.DevRepo.CreateObservedBranches(branch)
 		default:
 			panic(fmt.Sprintf("unknown branch type: %q", branchType))
 		}
 		state.initialLocalBranches = append(state.initialLocalBranches, branch)
-		if branchType == "feature" {
-			state.initialLineage.AddRow(branchName, "main")
-		}
 		if !isLocal {
 			state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
 			state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
@@ -1223,6 +1340,13 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^the local observed branch "([^"]+)"$`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		state.fixture.DevRepo.CreateObservedBranches(branch)
+		state.initialLocalBranches = append(state.initialLocalBranches, branch)
+		return nil
+	})
+
 	suite.Step(`^the (local )?perennial branches "([^"]+)" and "([^"]+)"$`, func(localStr, branch1Text, branch2Text string) error {
 		branch1 := gitdomain.NewLocalBranchName(branch1Text)
 		branch2 := gitdomain.NewLocalBranchName(branch2Text)
@@ -1255,8 +1379,8 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return state.fixture.DevRepo.Config.SetMainBranch(gitdomain.NewLocalBranchName(name))
 	})
 
-	suite.Step(`^the main branch is (?:now|still) "([^"]+)"$`, func(want string) error {
-		have := state.fixture.DevRepo.Config.MainBranch
+	suite.Step(`^the main branch is (?:now|still) "([^"]*)"$`, func(want string) error {
+		have := state.fixture.DevRepo.Config.FullConfig.MainBranch
 		if have.String() != want {
 			return fmt.Errorf("expected %q, got %q", want, have)
 		}
@@ -1271,11 +1395,28 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return fmt.Errorf("unexpected main branch setting %q", have)
 	})
 
+	suite.Step(`^an observed branch "([^"]+)"$`, func(name string) error {
+		branch := gitdomain.NewLocalBranchName(name)
+		state.fixture.DevRepo.CreateBranch(branch, "main")
+		state.initialLocalBranches = append(state.initialLocalBranches, branch)
+		state.fixture.DevRepo.PushBranchToRemote(branch, gitdomain.OriginRemote)
+		state.initialRemoteBranches = append(state.initialRemoteBranches, branch)
+		return state.fixture.DevRepo.Config.SetObservedBranches(gitdomain.NewLocalBranchNames(name))
+	})
+
+	suite.Step(`^the observed branches "([^"]+)" and "([^"]+)"$`, func(branch1, branch2 string) error {
+		return state.fixture.DevRepo.Config.SetObservedBranches(gitdomain.NewLocalBranchNames(branch1, branch2))
+	})
+
 	suite.Step(`^the origin is "([^"]*)"$`, func(origin string) error {
 		state.fixture.DevRepo.SetTestOrigin(origin)
 		return nil
 	})
 
+	suite.Step(`^the parked branches "([^"]+)" and "([^"]+)"$`, func(branch1, branch2 string) error {
+		return state.fixture.DevRepo.Config.SetParkedBranches(gitdomain.NewLocalBranchNames(branch1, branch2))
+	})
+
 	suite.Step(`^the perennial branches are "([^"]+)"$`, func(name string) error {
 		return state.fixture.DevRepo.Config.SetPerennialBranches(gitdomain.NewLocalBranchNames(name))
 	})
@@ -1318,6 +1459,30 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^there are (?:now|still) no contribution branches$`, func() error {
+		branches := state.fixture.DevRepo.Config.LocalGitConfig.ContributionBranches
+		if branches != nil && len(*branches) > 0 {
+			return fmt.Errorf("expected no contribution branches, got %q", branches)
+		}
+		return nil
+	})
+
+	suite.Step(`^there are (?:now|still) no observed branches$`, func() error {
+		branches := state.fixture.DevRepo.Config.LocalGitConfig.ObservedBranches
+		if branches != nil && len(*branches) > 0 {
+			return fmt.Errorf("expected no observed branches, got %q", branches)
+		}
+		return nil
+	})
+
+	suite.Step(`^there are (?:now|still) no parked branches$`, func() error {
+		branches := state.fixture.DevRepo.Config.LocalGitConfig.ParkedBranches
+		if branches != nil && len(*branches) > 0 {
+			return fmt.Errorf("expected no parked branches, got %q", branches)
+		}
+		return nil
+	})
+
 	suite.Step(`^there are (?:now|still) no perennial branches$`, func() error {
 		branches := state.fixture.DevRepo.Config.LocalGitConfig.PerennialBranches
 		if branches != nil && len(*branches) > 0 {
