@@ -78,17 +78,17 @@ func New(workingDir, homeDir, binDir string) TestRuntime {
 		BinDir:     binDir,
 	}
 	config, err := config.NewConfig(config.NewConfigArgs{
-		GlobalConfig: configdomain.EmptyPartialConfig(),
-		LocalConfig:  configdomain.EmptyPartialConfig(),
 		ConfigFile:   nil,
 		DryRun:       false,
+		GlobalConfig: configdomain.EmptyPartialConfig(),
+		LocalConfig:  configdomain.EmptyPartialConfig(),
 		Runner:       &runner,
 	})
 	if err != nil {
 		panic(err)
 	}
 	backendCommands := git.BackendCommands{
-		BackendRunner:      &runner,
+		Runner:             &runner,
 		DryRun:             false,
 		Config:             config,
 		CurrentBranchCache: &cache.LocalBranchWithPrevious{},
